Flask-dance Demo Registry — Flask Dance 1.2.0 documentation

# Flask-dance Demo Registry

## Contributing

Please create a branch and make a PR to add your project. Ideally, each project should contain a readme, source code and hosted demo.

## Twitter

source: | flask-dance-twitter-login-example
description: | Um simples app para fazer login no Twitter

source: | flask-dance-twitter-frontend
description: | A VueJS frontend and Python backend

## Github

source: | github-heroku-attack-rabbits
description: | Authenticate visitors with Github

Fork me on GitHub